# Generated by Django 3.1.5 on 2021-01-11 08:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("bifrost", "0002_stubmodel")]

    operations = [migrations.DeleteModel(name="StubModel")]
